# Utilities

This directory contains helpful scripts and utilities for the project.

## 🚀 UV Migration Script

### `migrate_to_uv.sh`

A comprehensive bash script that handles migration from pip/venv to UV package manager.

#### Features
- ✅ **Smart cleanup** - Removes cache files safely (excludes .venv)
- ✅ **UV installation** - Automatically installs UV if not present
- ✅ **Environment verification** - Tests dependencies and imports
- ✅ **Interactive prompts** - Asks before destructive operations
- ✅ **Colored output** - Easy to read progress indicators
- ✅ **Force mode** - Non-interactive mode for CI/automation

#### Usage

**Interactive mode (recommended):**
```bash
./utils/migrate_to_uv.sh
```

**Force mode (no prompts):**
```bash
./utils/migrate_to_uv.sh --force
```

#### What it does
1. **Pre-migration Analysis** - Counts cache files and checks project state
2. **UV Installation Check** - Verifies or installs UV
3. **Cache Cleanup** - Removes `__pycache__`, `.pyc`, and `.pytest_cache` files
4. **Environment Verification** - Tests UV installation and dependencies
5. **Old Files Cleanup** - Optionally removes old `venv/` and `requirements.txt`
6. **Final Verification** - Confirms everything is working

#### Safe to run multiple times
The script is idempotent - you can run it multiple times safely.

---

## 🔧 Other Utilities

### `get_telegram_chat_id.py`
Helper script to get your Telegram chat ID for bot configuration.

### `hyperliquid_account_analyzer.py`
Analyzes Hyperliquid account data and statistics.

---

## 💡 Tips

- Always run scripts from the project root directory
- Use `--force` mode for automated deployments
- Cache files will regenerate automatically when needed
- The migration script preserves all functionality 